# rasterarea


[![image](https://img.shields.io/pypi/v/rasterarea.svg)](https://pypi.python.org/pypi/rasterarea)
[![image](https://img.shields.io/conda/vn/conda-forge/rasterarea.svg)](https://anaconda.org/conda-forge/rasterarea)


**This package provides a interactive map inherit from geemap and ipyleaflet. Visuallized GRACE data, pick a point and get the time series plot of the value in this point. Calculate the area of the pixel and more!**


-   Free software: MIT license
-   Documentation: https://Feng96.github.io/rasterarea
    
## Install Instruction
-   Please have GDAL and localtileserver installed in your envirmental by command:
-   conda install -c conda-forge gdal
-   pip install localtileserver

## Features

-   Interactive Map from ipyleaflet
-   Inherit toolbar from geemap
-   Visuallized GRACE satellite data
-   Pick a point, return a plot of the time series plot of the value of the point

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
